<?php

namespace Luticate\Auth\Business;

use Luticate\Auth\DBO\LuticateUsersLoginDbo;
use Luticate\Utils\LuBusiness;
use Luticate\Auth\DataAccess\LuticateUsersDataAccess;
use Luticate\Auth\DBO\LuticateUsersDbo;

class LuticateUsersBusiness extends LuBusiness {

    protected static function getDataAccess()
    {
        return new LuticateUsersDataAccess();
    }

    protected static function badPassword()
    {
        abort(401, "Bad username/password");
    }

    public static function hashPassword($password)
    {
        return password_hash($password, PASSWORD_BCRYPT);
    }

    public static function verifyPassword($password, $hash)
    {
        return password_verify($password, $hash);
    }

    public static function getSalt($length = 10)
    {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    public static function getToken($user)
    {
        return JwtHelper::encode(array(JwtHelper::USER_KEY => $user->getId()));
    }

    public static function login($username, $password)
    {
        $user = LuticateUsersDataAccess::getByUsernameOrEmail($username);
        if (is_null($user))
            self::badPassword();
        if (!self::verifyPassword($password, $user->getPassword()))
            self::badPassword();
        $user = LuticateUsersLoginDbo::fromUserDbo($user);
        $user->setToken(self::getToken($user));
        return $user;
    }

    public static function add($username, $email, $password)
    {
        $hash = self::hashPassword($password);
        if (filter_var($username, FILTER_VALIDATE_EMAIL))
            self::badInput("Username can not be an email");
        if (!filter_var($email, FILTER_VALIDATE_EMAIL))
            self::badInput("Invalid email address");
        $user = LuticateUsersDataAccess::getByUsernameOrEmail($username);
        if (!is_null($user))
            self::badInput("Username already exists");
        $user = LuticateUsersDataAccess::getByUsernameOrEmail($email);
        if (!is_null($user))
            self::badInput("Email already used");

        $user = new LuticateUsersDbo();
        $user->setEmail($email);
        $user->setPassword($hash);
        $user->setUsername($username);
        $user->setSalt(self::getSalt());

        return LuticateUsersDataAccess::add($user);
    }
}